.. include:: README.rst

.. include:: multiprocessing.rst

Api Reference
-------------
.. toctree::
    :maxdepth: 2

    iot_v1/services
    iot_v1/types


Migration Guide
---------------

See the guide below for instructions on migrating to the 2.x release of this library.

.. toctree::
    :maxdepth: 2

    UPGRADING


Changelog
---------

For a list of all ``google-cloud-iot`` releases:

.. toctree::
   :maxdepth: 2

   changelog
